# Installation

[![CI Status](https://github.com/JGIBristol/digiqual/actions/workflows/ci_cd.yml/badge.svg)](https://github.com/JGIBristol/digiqual/actions) [![Python Version](https://img.shields.io/badge/python-3.10%2B-blue)](https://www.python.org/) [![License](https://img.shields.io/github/license/JGIBristol/digiqual)](LICENSE)

You can install `digiqual` directly from PyPI (or GitHub).

## Option 1: Install via uv (Recommended)

If you are managing a project with `uv`, add `digiqual` as a dependency:

- To install the latest stable release (v0.12.0):
```bash
uv add "digiqual"
```

- To install the latest development version (main branch from github):
```bash
uv add "digiqual @ git+https://github.com/JGIBristol/digiqual.git"
```

If you just want to install it into a virtual environment without modifying a project file (e.g., for a quick script), use pip interface:

```bash
uv pip install digiqual"
```

## Option 2: Install via standard pip

To install the latest stable release (v0.12.0):

```bash
pip install digiqual
```
To install the latest development version:

```bash
pip install "git+https://github.com/JGIBristol/digiqual.git"
```
